---
title: <span class="badge object-type-scalar"></span> Guarani
---
# <span class="badge object-type-scalar"></span> Guarani

Currency: Guaraní (₲)

## Definition

```python
# Currency: Guaraní (₲)
Guarani: typing.Literal["currencyPYG"] = "currencyPYG"
```
